"""
URLs for edX Enterprise's Consent application.
"""

from django.urls import include, path

urlpatterns = [
    path('consent/api/', include('consent.api.urls'),
         name='consent_api'
         ),
]



# Generated by Django 3.2.21 on 2023-09-21 10:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0184_auto_20230914_2057'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecustomer',
            name='career_engagement_network_message',
            field=models.TextField(blank=True, help_text='Message text shown on the learner portal dashboard for career engagement network.'),
        ),
        migrations.AddField(
            model_name='enterprisecustomer',
            name='enable_career_engagement_network_on_learner_portal',
            field=models.BooleanField(default=False, help_text='If checked, the learners will be able to see the link to CEN on the learner portal dashboard.', verbose_name='Allow navigation to career engagement network from learner portal dashboard'),
        ),
        migrations.AddField(
            model_name='historicalenterprisecustomer',
            name='career_engagement_network_message',
            field=models.TextField(blank=True, help_text='Message text shown on the learner portal dashboard for career engagement network.'),
        ),
        migrations.AddField(
            model_name='historicalenterprisecustomer',
            name='enable_career_engagement_network_on_learner_portal',
            field=models.BooleanField(default=False, help_text='If checked, the learners will be able to see the link to CEN on the learner portal dashboard.', verbose_name='Allow navigation to career engagement network from learner portal dashboard'),
        ),
    ]



# Generated by Django 3.2.20 on 2023-10-09 13:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0191_auto_20231006_0948'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecustomer',
            name='enable_demo_data_for_analytics_and_lpr',
            field=models.BooleanField(default=False, help_text='Display Demo data from analyitcs and learner progress report for demo customer.', verbose_name='Enable demo data from analytics and lpr'),
        ),
        migrations.AddField(
            model_name='historicalenterprisecustomer',
            name='enable_demo_data_for_analytics_and_lpr',
            field=models.BooleanField(default=False, help_text='Display Demo data from analyitcs and learner progress report for demo customer.', verbose_name='Enable demo data from analytics and lpr'),
        ),
    ]



# Generated by Django 3.2.22 on 2023-10-13 13:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0193_auto_20231005_1708'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecustomerssoconfiguration',
            name='errored_at',
            field=models.DateTimeField(blank=True, help_text='The date and time when the orchestrator encountered an error during configuration.', null=True),
        ),
        migrations.AddField(
            model_name='historicalenterprisecustomerssoconfiguration',
            name='errored_at',
            field=models.DateTimeField(blank=True, help_text='The date and time when the orchestrator encountered an error during configuration.', null=True),
        ),
    ]



# Generated by Django 3.2.18 on 2023-03-01 16:27

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0169_auto_20230222_1621'),
    ]

    operations = [
        migrations.AlterField(
            model_name='historicalsystemwideenterpriseuserroleassignment',
            name='enterprise_customer',
            field=models.ForeignKey(blank=True, db_constraint=False, help_text='The EnterpriseCustomer for which the role is assigned to for the provided user. Defaults to the first active Enterprise Customer that the user is linked to.If another Enterprise Customer object is desired, please first create the record then modify the enterprise customer field by using the drop down.', null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='enterprise.enterprisecustomer'),
        ),
        migrations.AlterField(
            model_name='systemwideenterpriseuserroleassignment',
            name='enterprise_customer',
            field=models.ForeignKey(blank=True, help_text='The EnterpriseCustomer for which the role is assigned to for the provided user. Defaults to the first active Enterprise Customer that the user is linked to.If another Enterprise Customer object is desired, please first create the record then modify the enterprise customer field by using the drop down.', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='system_wide_role_assignments', to='enterprise.enterprisecustomer'),
        ),
    ]



# Generated by Django 2.2.19 on 2022-05-17 16:26

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0157_make_field_nullable_before_removal'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='historicalsystemwideenterpriseuserroleassignment',
            name='is_active',
        ),
        migrations.RemoveField(
            model_name='systemwideenterpriseuserroleassignment',
            name='is_active',
        ),
    ]



"""
Viewsets for integrated_channels/v1/degreed/
"""
from rest_framework import exceptions, permissions, status, viewsets

from integrated_channels.api.v1.mixins import PermissionRequiredForIntegratedChannelMixin
from integrated_channels.degreed.models import DegreedEnterpriseCustomerConfiguration

from .serializers import DegreedConfigSerializer


class DegreedConfigurationViewSet(PermissionRequiredForIntegratedChannelMixin, viewsets.ModelViewSet):
    serializer_class = DegreedConfigSerializer
    permission_classes = (permissions.IsAuthenticated,)
    permission_required = 'enterprise.can_access_admin_dashboard'

    configuration_model = DegreedEnterpriseCustomerConfiguration



# Generated by Django 3.2.18 on 2023-07-07 07:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('consent', '0004_datasharingconsenttextoverrides'),
    ]

    operations = [
        migrations.AlterField(
            model_name='datasharingconsent',
            name='granted',
            field=models.BooleanField(help_text='Whether consent is granted.', null=True),
        ),
        migrations.AlterField(
            model_name='historicaldatasharingconsent',
            name='granted',
            field=models.BooleanField(help_text='Whether consent is granted.', null=True),
        ),
    ]



# Generated by Django 3.2.23 on 2024-02-16 07:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('integrated_channel', '0032_alter_integratedchannelapirequestlogs_endpoint'),
    ]

    operations = [
        migrations.AddField(
            model_name='integratedchannelapirequestlogs',
            name='channel_name',
            field=models.TextField(blank=True, help_text='Name of the integrated channel associated with this API call log record.'),
        ),
    ]



# Generated by Django 3.2.23 on 2024-01-30 06:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0198_alter_enterprisecourseenrollment_options'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecustomer',
            name='enable_academies',
            field=models.BooleanField(default=False, help_text='If checked, the learners will be able to see the academies on the learner portal dashboard.', verbose_name='Display academies screen'),
        ),
        migrations.AddField(
            model_name='historicalenterprisecustomer',
            name='enable_academies',
            field=models.BooleanField(default=False, help_text='If checked, the learners will be able to see the academies on the learner portal dashboard.', verbose_name='Display academies screen'),
        ),
    ]



# Generated by Django 3.2.15 on 2022-09-29 17:20

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('integrated_channel', '0021_remove_contentmetadataitemtransmission_api_response_body'),
        ('xapi', '0008_xapilearnerdatatransmissionaudit_friendly_status_message'),
    ]

    operations = [
        migrations.AddField(
            model_name='xapilearnerdatatransmissionaudit',
            name='api_record',
            field=models.OneToOneField(blank=True, help_text='Data pertaining to the transmissions API request response.', null=True, on_delete=django.db.models.deletion.CASCADE, to='integrated_channel.apiresponserecord'),
        ),
    ]



"""
Viewsets for integrated_channels/v1/moodle/
"""
from rest_framework import exceptions, permissions, status, viewsets

from integrated_channels.api.v1.mixins import PermissionRequiredForIntegratedChannelMixin
from integrated_channels.moodle.models import MoodleEnterpriseCustomerConfiguration

from .serializers import MoodleConfigSerializer


class MoodleConfigurationViewSet(PermissionRequiredForIntegratedChannelMixin, viewsets.ModelViewSet):
    serializer_class = MoodleConfigSerializer
    permission_classes = (permissions.IsAuthenticated,)
    permission_required = 'enterprise.can_access_admin_dashboard'

    configuration_model = MoodleEnterpriseCustomerConfiguration



# Generated by Django 3.2.15 on 2022-09-28 16:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0162_add_enable_executive_education_2U_fulfillment'),
    ]

    operations = [
        migrations.AlterField(
            model_name='enterprisecustomer',
            name='enable_learner_portal_offers',
            field=models.BooleanField(default=False, help_text='Specifies whether enterprise offers will be made known to learners in the learner portal.', verbose_name='Enable Learner Credit in the Learner Portal'),
        ),
        migrations.AlterField(
            model_name='historicalenterprisecustomer',
            name='enable_learner_portal_offers',
            field=models.BooleanField(default=False, help_text='Specifies whether enterprise offers will be made known to learners in the learner portal.', verbose_name='Enable Learner Credit in the Learner Portal'),
        ),
    ]



"""
enterprise_learner_portal app.
"""

from django.apps import AppConfig


class EnterpriseLearnerPortalConfig(AppConfig):
    """
    enterprise_learner_portal app config.
    """

    name = 'enterprise_learner_portal'



"""
Django management command for bulk updating EnterpriseCustomerCatalog record's EnterpriseCatalogQuery's.
"""

import logging
import shlex

from django.core.management import BaseCommand, CommandError

from enterprise.models import (
    BulkCatalogQueryUpdateCommandConfiguration,
    EnterpriseCatalogQuery,
    EnterpriseCustomerCatalog,
)

LOGGER = logging.getLogger(__name__)


class Command(BaseCommand):
    """
    Takes a new and old Enterprise Catalog Query ID, find all most recent records within the historical Enterprise
    Catalog table where enterprise catalog query ID is the old ID provided and updates the corresponding Enterprise
    Catalog table entries with the new ID.
    """
    help = "Updates specified EnterpriseCatalog's enterprise catalog query ID records with a provided new ID"

    def add_arguments(self, parser):
        parser.add_argument(
            '-o', '--old_id',
            metavar='OLD_ID',
            dest='old_id',
            help='Old catalog query ID to be replaced.'
        )
        parser.add_argument(
            '-n', '--new_id',
            metavar='NEW_ID',
            dest='new_id',
            help='New catalog query ID to replace the old one.'
        )
        parser.add_argument(
            '--args-from-database',
            action='store_true',
            help='Use arguments from the BulkCatalogQueryUpdateCommandConfiguration model instead of the command line'
        )

    def get_args_from_database(self):
        """
        Returns an options dictionary from the current BulkCatalogQueryUpdateCommandConfiguration model.
        """
        config = BulkCatalogQueryUpdateCommandConfiguration.current()
        if not config.enabled:
            raise CommandError(
                "BulkCatalogQueryUpdateCommandConfiguration is disabled, but --args-from-database was requested"
            )

        args = shlex.split(config.arguments)
        parser = self.create_parser("manage.py", "bulk_updates_catalog_query_id")

        return vars(parser.parse_args(args))

    def handle(self, *args, **options):
        """
        Entry point for management command execution.
        """
        LOGGER.info("Starting bulk update of EnterpriseCatalog's enterprise catalog query IDs")
        if options['args_from_database']:
            options = self.get_args_from_database()

        old_id = options.get('old_id')
        new_id = options.get('new_id')
        if not old_id:
            raise CommandError('You must specify an old query ID')
        if not new_id:
            raise CommandError('You must specify a new query ID')

        uuids_to_change = []
        if EnterpriseCatalogQuery.objects.filter(id=new_id).first():
            # pylint: disable=no-member
            catalogs_to_change = EnterpriseCustomerCatalog.history.filter(enterprise_catalog_query_id=old_id).order_by(
                '-modified'
            ).distinct()
            # pylint: enable=no-member
            for catalog in catalogs_to_change:
                if not catalog.next_record and catalog.get_history_type_display() != 'Deleted':
                    uuids_to_change.append(catalog.uuid)

            EnterpriseCustomerCatalog.objects.filter(uuid__in=uuids_to_change).update(
                enterprise_catalog_query_id=new_id
            )
            LOGGER.info(
                "Completed bulk update of EnterpriseCatalog's enterprise catalog queries with ID={} to ID={}".format(
                    old_id,
                    new_id
                )
            )
        else:
            LOGGER.exception("Could not find query with ID={}".format(new_id))



"""
Deletes records from the IntegratedChannelAPIRequestLogs model that are older than one month..
"""
from datetime import timedelta
from logging import getLogger

from django.contrib import auth
from django.core.management.base import BaseCommand
from django.utils import timezone
from django.utils.translation import gettext as _

from integrated_channels.utils import integrated_channel_request_log_model

User = auth.get_user_model()
LOGGER = getLogger(__name__)


class Command(BaseCommand):
    """
    Management command to delete old records from the IntegratedChannelAPIRequestLogs model.
    """
    help = _('''
    This management command deletes records from the IntegratedChannelAPIRequestLogs model that are older than one month
    ''')

    def add_arguments(self, parser):
        """
        Adds custom arguments to the parser.
        """
        parser.add_argument('time_duration', nargs='?', type=int, default=30,
                            help='The duration in days for deleting old records. Default is 30 days.')

    def handle(self, *args, **options):
        """
        Remove the duplicated transmission audit records for integration channels.
        """
        time_duration = options['time_duration']
        time_threshold = timezone.now() - timedelta(days=time_duration)
        deleted_count, _ = integrated_channel_request_log_model().objects.filter(created__lt=time_threshold).delete()

        LOGGER.info(f"Deleting records from IntegratedChannelAPIRequestLogs. Total records to delete: {deleted_count}")



# Generated by Django 3.2.21 on 2023-10-05 17:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0192_auto_20231009_1302'),
    ]

    operations = [
        migrations.AlterField(
            model_name='enterprisecustomer',
            name='contact_email',
            field=models.EmailField(blank=True, help_text='Email linked on learner portal as public point of contact, will default to all admin users associated with this customer if left blank.', max_length=254, null=True, verbose_name='Customer admin contact email:'),
        ),
        migrations.AlterField(
            model_name='historicalenterprisecustomer',
            name='contact_email',
            field=models.EmailField(blank=True, help_text='Email linked on learner portal as public point of contact, will default to all admin users associated with this customer if left blank.', max_length=254, null=True, verbose_name='Customer admin contact email:'),
        ),
    ]
